@@ -105,7 +105,7 @@ class ActiveResource(object):
             method = 'POST'
         
         dict([(k, getattr(self, k)) for k in self.Meta.changed])
-        status, xml = self.__class__._make_request(obj=self, method=method, params=params)
+        status, xml = self.__class__._make_request(obj=self, method=method)
         
         if not str(status[0]).startswith('2'):
             return False
